@@ -36,9 +36,13 @@ class EnrichClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Deletes an existing enrich policy and its enrich index.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.14/delete-enrich-policy-api.html>`_
+          <p>Delete an enrich policy.
+          Deletes an existing enrich policy and its enrich index.</p>
+
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/delete-enrich-policy-api.html>`_
 
         :param name: Enrich policy to delete.
         """
@@ -77,9 +81,13 @@ class EnrichClient(NamespacedClient):
         wait_for_completion: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Creates the enrich index for an existing enrich policy.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.14/execute-enrich-policy-api.html>`_
+          <p>Run an enrich policy.
+          Create the enrich index for an existing enrich policy.</p>
+
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/execute-enrich-policy-api.html>`_
 
         :param name: Enrich policy to execute.
         :param wait_for_completion: If `true`, the request blocks other enrich policy
@@ -121,9 +129,13 @@ class EnrichClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Gets information about an enrich policy.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.14/get-enrich-policy-api.html>`_
+          <p>Get an enrich policy.
+          Returns information about an enrich policy.</p>
+
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/get-enrich-policy-api.html>`_
 
         :param name: Comma-separated list of enrich policy names used to limit the request.
             To return information for all enrich policies, omit this parameter.
@@ -171,9 +183,13 @@ class EnrichClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Creates a new enrich policy.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.14/put-enrich-policy-api.html>`_
+          <p>Create an enrich policy.
+          Creates an enrich policy.</p>
+
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/put-enrich-policy-api.html>`_
 
         :param name: Name of the enrich policy to create or update.
         :param geo_match: Matches enrich data to incoming documents based on a `geo_shape`
@@ -224,10 +240,13 @@ class EnrichClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Gets enrich coordinator statistics and information about enrich policies that
-        are currently executing.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.14/enrich-stats-api.html>`_
+          <p>Get enrich stats.
+          Returns enrich coordinator statistics and information about enrich policies that are currently executing.</p>
+
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.17/enrich-stats-api.html>`_
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_enrich/_stats"
